@@ -1,7 +1,6 @@
 import asyncio
 import signal
 from collections.abc import Awaitable, Coroutine
-from functools import partial
 from typing import Any
 
 from kosong.chat_provider import APIStatusError, ChatProviderError
@@ -160,10 +159,13 @@ class ShellApp:
         loop.add_signal_handler(signal.SIGINT, _handler)
 
         try:
+            # Use lambda to pass cancel_event via closure
             await run_soul(
                 self.soul,
                 command,
-                partial(visualize, initial_status=self.soul.status),
+                lambda wire: visualize(
+                    wire, initial_status=self.soul.status, cancel_event=cancel_event
+                ),
                 cancel_event,
             )
             return True
